<?php

namespace Assetdocs\Incident\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Incident\Interfaces\IncidentRepositoryInterface;
use Assetdocs\Incident\Repositories\Presenter\IncidentItemTransformer;

/**
 * Pubic API controller class.
 */
class IncidentApiController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Assetdocs\Incident\Interfaces\IncidentRepositoryInterface $incident
     *
     * @return type
     */
    public function __construct(IncidentRepositoryInterface $incident)
    {
        $this->middleware('api');

        $this->repository = $incident;
        parent::__construct();
    }

    /**
     * Show incident's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $incidents = $this->repository
            ->pushCriteria(new \Assetdocs\Incident\Repositories\Criteria\IncidentPublicCriteria())
            ->setPresenter('\\Assetdocs\\Incident\\Repositories\\Presenter\\IncidentListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $incidents['code'] = 2000;
        return response()->json($incidents)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show incident.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $incident = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($incident)) {
            $incident         = $this->itemPresenter($module, new IncidentItemTransformer);
            $incident['code'] = 2001;
            return response()->json($incident)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
